==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
